# Log-based testing

[![Build](https://github.com/etianen/logot/actions/workflows/build.yml/badge.svg)](https://github.com/etianen/logot/actions/workflows/build.yml)

📖 [Read the docs](https://logot.readthedocs.io) 📖
